Plugin Models
=============

Plugin models are provided by different plugins. They are not associated by default with the core models of Cibyl, but only when the plugin is being used.
In addition, the way the plugin models are associated with core models, is very much depends on the implementation of the plugin.

An example of plugin models can be seen in `openstack plugin <../plugins/openstack.html#models>`_ page
